# swagger-client
# Introduction 
The *Humanitec API* allows you to automate and integrate Humanitec into your developer and operational workflows. The API is a REST based API. It is based around a set of concepts:  * Core * External Resources * Sets and Deltas  ## Authentication Almost all requests made to the Humanitec API require Authentication. Humanitec provides 2 ways of authenticating with the API: `Bearer` and `JWT`.  

### Bearer Authentication 

This form of authentication makes use of a **static token**. It is intended to be used when machines interact with the Humanitec API. Bearer tokens should be used for very narrow purposes. This allows for the token to be revoked if it is compromised and so limit the scope of exposure. New Bearer tokens can be obtained via the UI:  

1. Log into Humanitec at https://app.humanitec.io 
1. Go to **Organization Settings** 
1. Select **API tokens** 
1. Enter a *name* for the new token and click on **Generate new token**  

The token is passed to the API via the `Authorization` header. Assuming the issued token is `HUMANITEC_TOKEN`, the request could be made as follows:  ```     curl -H 'Authorization: Bearer HUMANITEC_TOKEN' https://api.humanitec.io/orgs/my-org/apps ```  

### JWT Authentication 

This form of authentication makes use of a **JSON Web Token (JWT)**. It is intended to be used when humans interact with the Humanitec API. JWTs expire after a period of time. This means that a new JWT will need to be generated regularly. This makes them well suited to working in short sessions, but not for automation. (See Bearer Authentication.) The token is passed to the API via the `Authorization` header. Assuming the issued token is `HUMANITEC_JWT`, the request could be made as follows:  

```
curl -H 'Authorization: JWT HUMANITEC_JWT' https://api.humanitec.io/orgs/my-org/apps 
``` 

## Content Types 
All of the Humanitec API unless explicitly only accepts content types of `application/json` and will always return valid `application/json` or an empty response.  

## Response Codes 

### Success 

Any response code in the `2xx` range should be regarded as success.  

| **Code** | **Meaning** | 
| --- | --- | 
| `200` | Success | 
| `201` | Success (In future, `201` will be replaced by `200`) | 
| `204` | Success, but no content in response |  

_Note: We plan to simplify the interface by replacing 201 with 200 status codes._  

### Failure 

Any response code in the `4xx` should be regarded as an error which can be rectified by the client. `5xx` error codes indicate errors that cannot be corrected by the client.  

| **Code** | **Meaning** | 
| --- | --- | 
| `400` | General error. (Body will contain details) | 
| `401` | Attempt to access protected resource without `Authorization` Header. | 
| `403` | The `Bearer` or `JWT` does not grant access to the requested resource. | 
| `404` | Resource not found. | 
| `405` | Method not allowed | 
| `409` | Conflict. Usually indicated a resource with that ID already exists. | 
| `422` | Unprocessable Entity. The body was not valid JSON, was empty or contained an object different from what was expected. | 
| `429` | Too many requests - request rate limit has been reached. | 
| `500` | Internal Error. If it occurs repeatedly, contact support. | 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.24.1
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

```sh
pip install unofficial-humanitec-client
```

Then import the package:
```python
import swagger_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.AccountTypeApi(swagger_client.ApiClient(configuration))
org_id = 'org_id_example' # str | The Organization ID.  

try:
    # List Resource Account Types available to the organization.
    api_response = api_instance.orgs_org_id_resources_account_types_get(org_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccountTypeApi->orgs_org_id_resources_account_types_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.humanitec.io/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountTypeApi* | [**orgs_org_id_resources_account_types_get**](docs/AccountTypeApi.md#orgs_org_id_resources_account_types_get) | **GET** /orgs/{orgId}/resources/account-types | List Resource Account Types available to the organization.
*ActiveResourceApi* | [**orgs_org_id_apps_app_id_envs_env_id_resources_get**](docs/ActiveResourceApi.md#orgs_org_id_apps_app_id_envs_env_id_resources_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/resources | List Active Resources provisioned in an environment.
*ActiveResourceApi* | [**orgs_org_id_apps_app_id_envs_env_id_resources_type_res_id_delete**](docs/ActiveResourceApi.md#orgs_org_id_apps_app_id_envs_env_id_resources_type_res_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/resources/{type}/{resId} | Delete Active Resources.
*ActiveResourceApi* | [**orgs_org_id_resources_defs_def_id_resources_get**](docs/ActiveResourceApi.md#orgs_org_id_resources_defs_def_id_resources_get) | **GET** /orgs/{orgId}/resources/defs/{defId}/resources | List Active Resources provisioned via a specific Resource Definition.
*ApplicationApi* | [**orgs_org_id_apps_app_id_delete**](docs/ApplicationApi.md#orgs_org_id_apps_app_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId} | Delete an Application
*ApplicationApi* | [**orgs_org_id_apps_app_id_get**](docs/ApplicationApi.md#orgs_org_id_apps_app_id_get) | **GET** /orgs/{orgId}/apps/{appId} | Get an existing Application
*ApplicationApi* | [**orgs_org_id_apps_get**](docs/ApplicationApi.md#orgs_org_id_apps_get) | **GET** /orgs/{orgId}/apps | List all Applications in an Organization.
*ApplicationApi* | [**orgs_org_id_apps_post**](docs/ApplicationApi.md#orgs_org_id_apps_post) | **POST** /orgs/{orgId}/apps | Add a new Application to an Organization
*ArtefactApi* | [**orgs_org_id_artefacts_artefact_id_delete**](docs/ArtefactApi.md#orgs_org_id_artefacts_artefact_id_delete) | **DELETE** /orgs/{orgId}/artefacts/{artefactId} | Delete Artefact and all related Artefact Versions
*ArtefactApi* | [**orgs_org_id_artefacts_get**](docs/ArtefactApi.md#orgs_org_id_artefacts_get) | **GET** /orgs/{orgId}/artefacts | List all Artefacts.
*ArtefactVersionApi* | [**orgs_org_id_artefact_versions_artefact_version_id_get**](docs/ArtefactVersionApi.md#orgs_org_id_artefact_versions_artefact_version_id_get) | **GET** /orgs/{orgId}/artefact-versions/{artefactVersionId} | Get an Artefacts Versions.
*ArtefactVersionApi* | [**orgs_org_id_artefact_versions_get**](docs/ArtefactVersionApi.md#orgs_org_id_artefact_versions_get) | **GET** /orgs/{orgId}/artefact-versions | List all Artefacts Versions.
*ArtefactVersionApi* | [**orgs_org_id_artefact_versions_post**](docs/ArtefactVersionApi.md#orgs_org_id_artefact_versions_post) | **POST** /orgs/{orgId}/artefact-versions | Register a new Artefact Version with your organization.
*ArtefactVersionApi* | [**orgs_org_id_artefacts_artefact_id_versions_get**](docs/ArtefactVersionApi.md#orgs_org_id_artefacts_artefact_id_versions_get) | **GET** /orgs/{orgId}/artefacts/{artefactId}/versions | List all Artefact Versions of an Artefact.
*ArtefactVersionApi* | [**orgs_org_id_artefacts_artefact_id_versions_version_id_patch**](docs/ArtefactVersionApi.md#orgs_org_id_artefacts_artefact_id_versions_version_id_patch) | **PATCH** /orgs/{orgId}/artefacts/{artefactId}/versions/{versionId} | Update Version of an Artefact.
*AutomationRuleApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_get**](docs/AutomationRuleApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules | List all Automation Rules in an Environment.
*AutomationRuleApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_post**](docs/AutomationRuleApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules | Create a new Automation Rule for an Environment.
*AutomationRuleApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_delete**](docs/AutomationRuleApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules/{ruleId} | Delete Automation Rule from an Environment.
*AutomationRuleApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_get**](docs/AutomationRuleApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules/{ruleId} | Get a specific Automation Rule for an Environment.
*AutomationRuleApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_put**](docs/AutomationRuleApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules/{ruleId} | Update an existing Automation Rule for an Environment.
*DeltaApi* | [**get_delta**](docs/DeltaApi.md#get_delta) | **GET** /orgs/{orgId}/apps/{appId}/deltas/{deltaId} | Fetch an existing Delta
*DeltaApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_metadata_archived_put**](docs/DeltaApi.md#orgs_org_id_apps_app_id_deltas_delta_id_metadata_archived_put) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId}/metadata/archived | Mark a Delta as \&quot;archived\&quot;
*DeltaApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_metadata_env_id_put**](docs/DeltaApi.md#orgs_org_id_apps_app_id_deltas_delta_id_metadata_env_id_put) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId}/metadata/env_id | Change the Environment of a Delta
*DeltaApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_metadata_name_put**](docs/DeltaApi.md#orgs_org_id_apps_app_id_deltas_delta_id_metadata_name_put) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId}/metadata/name | Change the name of a Delta
*DeltaApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_patch**](docs/DeltaApi.md#orgs_org_id_apps_app_id_deltas_delta_id_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/deltas/{deltaId} | Update an existing Delta
*DeltaApi* | [**orgs_org_id_apps_app_id_deltas_get**](docs/DeltaApi.md#orgs_org_id_apps_app_id_deltas_get) | **GET** /orgs/{orgId}/apps/{appId}/deltas | List Deltas in an Application
*DeltaApi* | [**orgs_org_id_apps_app_id_deltas_post**](docs/DeltaApi.md#orgs_org_id_apps_app_id_deltas_post) | **POST** /orgs/{orgId}/apps/{appId}/deltas | Create a new Delta
*DeltaApi* | [**put_delta**](docs/DeltaApi.md#put_delta) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId} | Update an existing Delta
*DeploymentApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_errors_get**](docs/DeploymentApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_errors_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys/{deployId}/errors | List errors that occurred in a Deployment.
*DeploymentApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_get**](docs/DeploymentApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys/{deployId} | Get a specific Deployment.
*DeploymentApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_get**](docs/DeploymentApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys | List Deployments in an Environment.
*DeploymentApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_post**](docs/DeploymentApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys | Start a new Deployment.
*DriverDefinitionApi* | [**orgs_org_id_resources_drivers_driver_id_delete**](docs/DriverDefinitionApi.md#orgs_org_id_resources_drivers_driver_id_delete) | **DELETE** /orgs/{orgId}/resources/drivers/{driverId} | Delete a Resources Driver.
*DriverDefinitionApi* | [**orgs_org_id_resources_drivers_driver_id_get**](docs/DriverDefinitionApi.md#orgs_org_id_resources_drivers_driver_id_get) | **GET** /orgs/{orgId}/resources/drivers/{driverId} | Get a Resource Driver.
*DriverDefinitionApi* | [**orgs_org_id_resources_drivers_driver_id_put**](docs/DriverDefinitionApi.md#orgs_org_id_resources_drivers_driver_id_put) | **PUT** /orgs/{orgId}/resources/drivers/{driverId} | Update a Resource Driver.
*DriverDefinitionApi* | [**orgs_org_id_resources_drivers_get**](docs/DriverDefinitionApi.md#orgs_org_id_resources_drivers_get) | **GET** /orgs/{orgId}/resources/drivers | List Resource Drivers.
*DriverDefinitionApi* | [**orgs_org_id_resources_drivers_post**](docs/DriverDefinitionApi.md#orgs_org_id_resources_drivers_post) | **POST** /orgs/{orgId}/resources/drivers | Register a new Resource Driver.
*EnvironmentApi* | [**orgs_org_id_apps_app_id_envs_env_id_delete**](docs/EnvironmentApi.md#orgs_org_id_apps_app_id_envs_env_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId} | Delete a specific Environment.
*EnvironmentApi* | [**orgs_org_id_apps_app_id_envs_env_id_from_deploy_id_put**](docs/EnvironmentApi.md#orgs_org_id_apps_app_id_envs_env_id_from_deploy_id_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/from_deploy_id | Rebase to a different Deployment.
*EnvironmentApi* | [**orgs_org_id_apps_app_id_envs_env_id_get**](docs/EnvironmentApi.md#orgs_org_id_apps_app_id_envs_env_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId} | Get a specific Environment.
*EnvironmentApi* | [**orgs_org_id_apps_app_id_envs_get**](docs/EnvironmentApi.md#orgs_org_id_apps_app_id_envs_get) | **GET** /orgs/{orgId}/apps/{appId}/envs | List all Environments.
*EnvironmentApi* | [**orgs_org_id_apps_app_id_envs_post**](docs/EnvironmentApi.md#orgs_org_id_apps_app_id_envs_post) | **POST** /orgs/{orgId}/apps/{appId}/envs | Add a new Environment to an Application.
*EnvironmentTypeApi* | [**orgs_org_id_env_types_env_type_id_delete**](docs/EnvironmentTypeApi.md#orgs_org_id_env_types_env_type_id_delete) | **DELETE** /orgs/{orgId}/env-types/{envTypeId} | Deletes an Environment Type
*EnvironmentTypeApi* | [**orgs_org_id_env_types_env_type_id_get**](docs/EnvironmentTypeApi.md#orgs_org_id_env_types_env_type_id_get) | **GET** /orgs/{orgId}/env-types/{envTypeId} | Get an Environment Type
*EnvironmentTypeApi* | [**orgs_org_id_env_types_get**](docs/EnvironmentTypeApi.md#orgs_org_id_env_types_get) | **GET** /orgs/{orgId}/env-types | List all Environment Types
*EnvironmentTypeApi* | [**orgs_org_id_env_types_post**](docs/EnvironmentTypeApi.md#orgs_org_id_env_types_post) | **POST** /orgs/{orgId}/env-types | Add a new Environment Type
*EventApi* | [**orgs_org_id_apps_app_id_jobs_delete**](docs/EventApi.md#orgs_org_id_apps_app_id_jobs_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/jobs | Deletes all Jobs for the Application
*EventApi* | [**orgs_org_id_apps_app_id_webhooks_get**](docs/EventApi.md#orgs_org_id_apps_app_id_webhooks_get) | **GET** /orgs/{orgId}/apps/{appId}/webhooks | List Webhooks
*EventApi* | [**orgs_org_id_apps_app_id_webhooks_job_id_delete**](docs/EventApi.md#orgs_org_id_apps_app_id_webhooks_job_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/webhooks/{jobId} | Delete a Webhook
*EventApi* | [**orgs_org_id_apps_app_id_webhooks_job_id_get**](docs/EventApi.md#orgs_org_id_apps_app_id_webhooks_job_id_get) | **GET** /orgs/{orgId}/apps/{appId}/webhooks/{jobId} | Get a Webhook
*EventApi* | [**orgs_org_id_apps_app_id_webhooks_job_id_patch**](docs/EventApi.md#orgs_org_id_apps_app_id_webhooks_job_id_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/webhooks/{jobId} | Update a Webhook
*EventApi* | [**orgs_org_id_apps_app_id_webhooks_post**](docs/EventApi.md#orgs_org_id_apps_app_id_webhooks_post) | **POST** /orgs/{orgId}/apps/{appId}/webhooks | Create a new Webhook
*EventApi* | [**orgs_org_id_events_get**](docs/EventApi.md#orgs_org_id_events_get) | **GET** /orgs/{orgId}/events | List Events
*HumanitecPublicKeysApi* | [**get_humanitec_public_keys**](docs/HumanitecPublicKeysApi.md#get_humanitec_public_keys) | **GET** /orgs/{orgId}/humanitec-keys | List all the public keys Humanitec shares with an organization.
*ImageApi* | [**orgs_org_id_images_get**](docs/ImageApi.md#orgs_org_id_images_get) | **GET** /orgs/{orgId}/images | List all Container Images
*ImageApi* | [**orgs_org_id_images_image_id_builds_get**](docs/ImageApi.md#orgs_org_id_images_image_id_builds_get) | **GET** /orgs/{orgId}/images/{imageId}/builds | Lists all the Builds of an Image
*ImageApi* | [**orgs_org_id_images_image_id_builds_post**](docs/ImageApi.md#orgs_org_id_images_image_id_builds_post) | **POST** /orgs/{orgId}/images/{imageId}/builds | Add a new Image Build
*ImageApi* | [**orgs_org_id_images_image_id_get**](docs/ImageApi.md#orgs_org_id_images_image_id_get) | **GET** /orgs/{orgId}/images/{imageId} | Get a specific Image Object
*MatchingCriteriaApi* | [**orgs_org_id_resources_defs_def_id_criteria_criteria_id_delete**](docs/MatchingCriteriaApi.md#orgs_org_id_resources_defs_def_id_criteria_criteria_id_delete) | **DELETE** /orgs/{orgId}/resources/defs/{defId}/criteria/{criteriaId} | Delete a Matching Criteria from a Resource Definition.
*MatchingCriteriaApi* | [**orgs_org_id_resources_defs_def_id_criteria_post**](docs/MatchingCriteriaApi.md#orgs_org_id_resources_defs_def_id_criteria_post) | **POST** /orgs/{orgId}/resources/defs/{defId}/criteria | Add a new Matching Criteria to a Resource Definition.
*OrganizationApi* | [**orgs_get**](docs/OrganizationApi.md#orgs_get) | **GET** /orgs | List active organizations the user has access to.
*OrganizationApi* | [**orgs_org_id_get**](docs/OrganizationApi.md#orgs_org_id_get) | **GET** /orgs/{orgId} | Get the specified Organization.
*PipelineApprovalsApi* | [**approve_approval_request**](docs/PipelineApprovalsApi.md#approve_approval_request) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/approvals/{approvalId}/approve | Approve the approval request
*PipelineApprovalsApi* | [**deny_approval_request**](docs/PipelineApprovalsApi.md#deny_approval_request) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/approvals/{approvalId}/deny | Deny the approval request
*PipelineApprovalsApi* | [**get_approval_request**](docs/PipelineApprovalsApi.md#get_approval_request) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/approvals/{approvalId} | Get an approval request
*PipelineApprovalsApi* | [**list_approval_requests**](docs/PipelineApprovalsApi.md#list_approval_requests) | **GET** /orgs/{orgId}/apps/{appId}/approvals | List of the approval requests
*PipelineRunsApi* | [**cancel_run**](docs/PipelineRunsApi.md#cancel_run) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/cancel | Cancel a Run within an Pipeline.
*PipelineRunsApi* | [**create_pipeline_run**](docs/PipelineRunsApi.md#create_pipeline_run) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs | Create a run within a pipeline.
*PipelineRunsApi* | [**delete_run**](docs/PipelineRunsApi.md#delete_run) | **DELETE** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId} | Deleting a completed Run within a Pipeline.
*PipelineRunsApi* | [**get_run**](docs/PipelineRunsApi.md#get_run) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId} | Get a run within an pipeline.
*PipelineRunsApi* | [**get_run_job**](docs/PipelineRunsApi.md#get_run_job) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId} | List the details of a Job including Step information
*PipelineRunsApi* | [**list_pipeline_runs**](docs/PipelineRunsApi.md#list_pipeline_runs) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs | List runs within a pipeline.
*PipelineRunsApi* | [**list_pipeline_runs_by_org**](docs/PipelineRunsApi.md#list_pipeline_runs_by_org) | **GET** /orgs/{orgId}/pipeline-runs | List all pipeline runs within the Org. This can be filtered by app, pipeline, and status.
*PipelineRunsApi* | [**list_run_job_step_logs**](docs/PipelineRunsApi.md#list_run_job_step_logs) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/steps/{stepIndex}/logs | Get a page of log output for a given step within a job.
*PipelineRunsApi* | [**list_run_jobs**](docs/PipelineRunsApi.md#list_run_jobs) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs | List the details of the jobs with in a pipeline run.
*PipelineRunsApi* | [**restart_run**](docs/PipelineRunsApi.md#restart_run) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/restart | Restart a Run within an Pipeline by cloning it with the same trigger and inputs.
*PipelinesApi* | [**create_pipeline**](docs/PipelinesApi.md#create_pipeline) | **POST** /orgs/{orgId}/apps/{appId}/pipelines | Create a Pipeline within an Application.
*PipelinesApi* | [**delete_pipeline**](docs/PipelinesApi.md#delete_pipeline) | **DELETE** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId} | Delete a pipeline within an application.
*PipelinesApi* | [**get_latest_pipeline_definition_schema**](docs/PipelinesApi.md#get_latest_pipeline_definition_schema) | **GET** /orgs/{orgId}/pipeline-schemas/latest | Gets the latest pipeline schema
*PipelinesApi* | [**get_pipeline**](docs/PipelinesApi.md#get_pipeline) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId} | Get a Pipeline within an Application.
*PipelinesApi* | [**get_pipeline_definition**](docs/PipelinesApi.md#get_pipeline_definition) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/schema | Get a pipeline schema.
*PipelinesApi* | [**list_pipeline_versions**](docs/PipelinesApi.md#list_pipeline_versions) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/versions | List all versions of the pipeline
*PipelinesApi* | [**list_pipelines**](docs/PipelinesApi.md#list_pipelines) | **GET** /orgs/{orgId}/apps/{appId}/pipelines | List Pipelines within an Application.
*PipelinesApi* | [**list_pipelines_in_org**](docs/PipelinesApi.md#list_pipelines_in_org) | **GET** /orgs/{orgId}/pipelines | List all Pipelines within an Organization. This can be filtered by Application.
*PipelinesApi* | [**update_pipeline**](docs/PipelinesApi.md#update_pipeline) | **PATCH** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId} | update a Pipeline within an Application.
*PublicKeysApi* | [**create_public_key**](docs/PublicKeysApi.md#create_public_key) | **POST** /orgs/{orgId}/keys | Associate a new RSA public key to an organization.
*PublicKeysApi* | [**delete_public_key**](docs/PublicKeysApi.md#delete_public_key) | **DELETE** /orgs/{orgId}/keys/{keyId} | Delete a public key associated to an organization.
*PublicKeysApi* | [**get_public_key**](docs/PublicKeysApi.md#get_public_key) | **GET** /orgs/{orgId}/keys/{keyId} | Retrieve a single public key associated to an organization.
*PublicKeysApi* | [**get_public_keys**](docs/PublicKeysApi.md#get_public_keys) | **GET** /orgs/{orgId}/keys | List all public keys associated to an organization.
*RegistryApi* | [**orgs_org_id_registries_get**](docs/RegistryApi.md#orgs_org_id_registries_get) | **GET** /orgs/{orgId}/registries | Lists available registries for the organization.
*RegistryApi* | [**orgs_org_id_registries_post**](docs/RegistryApi.md#orgs_org_id_registries_post) | **POST** /orgs/{orgId}/registries | Creates a new registry record.
*RegistryApi* | [**orgs_org_id_registries_reg_id_creds_get**](docs/RegistryApi.md#orgs_org_id_registries_reg_id_creds_get) | **GET** /orgs/{orgId}/registries/{regId}/creds | Returns current account credentials or secret details for the registry.
*RegistryApi* | [**orgs_org_id_registries_reg_id_delete**](docs/RegistryApi.md#orgs_org_id_registries_reg_id_delete) | **DELETE** /orgs/{orgId}/registries/{regId} | Deletes an existing registry record and all associated credentials and secrets.
*RegistryApi* | [**orgs_org_id_registries_reg_id_get**](docs/RegistryApi.md#orgs_org_id_registries_reg_id_get) | **GET** /orgs/{orgId}/registries/{regId} | Loads a registry record details.
*RegistryApi* | [**orgs_org_id_registries_reg_id_patch**](docs/RegistryApi.md#orgs_org_id_registries_reg_id_patch) | **PATCH** /orgs/{orgId}/registries/{regId} | Updates (patches) an existing registry record.
*ResourceAccountApi* | [**orgs_org_id_resources_accounts_acc_id_delete**](docs/ResourceAccountApi.md#orgs_org_id_resources_accounts_acc_id_delete) | **DELETE** /orgs/{orgId}/resources/accounts/{accId} | Delete an unused Resource Account.
*ResourceAccountApi* | [**orgs_org_id_resources_accounts_acc_id_get**](docs/ResourceAccountApi.md#orgs_org_id_resources_accounts_acc_id_get) | **GET** /orgs/{orgId}/resources/accounts/{accId} | Get a Resource Account.
*ResourceAccountApi* | [**orgs_org_id_resources_accounts_acc_id_patch**](docs/ResourceAccountApi.md#orgs_org_id_resources_accounts_acc_id_patch) | **PATCH** /orgs/{orgId}/resources/accounts/{accId} | Update a Resource Account.
*ResourceAccountApi* | [**orgs_org_id_resources_accounts_get**](docs/ResourceAccountApi.md#orgs_org_id_resources_accounts_get) | **GET** /orgs/{orgId}/resources/accounts | List Resource Accounts in the organization.
*ResourceAccountApi* | [**orgs_org_id_resources_accounts_post**](docs/ResourceAccountApi.md#orgs_org_id_resources_accounts_post) | **POST** /orgs/{orgId}/resources/accounts | Create a new Resource Account in the organization.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_criteria_criteria_id_delete**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_criteria_criteria_id_delete) | **DELETE** /orgs/{orgId}/resources/defs/{defId}/criteria/{criteriaId} | Delete a Matching Criteria from a Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_criteria_post**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_criteria_post) | **POST** /orgs/{orgId}/resources/defs/{defId}/criteria | Add a new Matching Criteria to a Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_delete**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_delete) | **DELETE** /orgs/{orgId}/resources/defs/{defId} | Delete a Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_get**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_get) | **GET** /orgs/{orgId}/resources/defs/{defId} | Get a specific Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_patch**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_patch) | **PATCH** /orgs/{orgId}/resources/defs/{defId} | Update a Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_put**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_put) | **PUT** /orgs/{orgId}/resources/defs/{defId} | Update a Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_def_id_resources_get**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_def_id_resources_get) | **GET** /orgs/{orgId}/resources/defs/{defId}/resources | List Active Resources provisioned via a specific Resource Definition.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_get**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_get) | **GET** /orgs/{orgId}/resources/defs | List Resource Definitions.
*ResourceDefinitionApi* | [**orgs_org_id_resources_defs_post**](docs/ResourceDefinitionApi.md#orgs_org_id_resources_defs_post) | **POST** /orgs/{orgId}/resources/defs | Create a new Resource Definition.
*ResourceProvisionApi* | [**orgs_org_id_apps_app_id_envs_env_id_resources_graph_post**](docs/ResourceProvisionApi.md#orgs_org_id_apps_app_id_envs_env_id_resources_graph_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/resources/graph | Lists the resource objects that hold the information needed to provision the resources specified in the request and the resources they depend on.
*ResourceTypeApi* | [**orgs_org_id_resources_types_get**](docs/ResourceTypeApi.md#orgs_org_id_resources_types_get) | **GET** /orgs/{orgId}/resources/types | List Resource Types.
*RuntimeInfoApi* | [**orgs_org_id_apps_app_id_envs_env_id_runtime_get**](docs/RuntimeInfoApi.md#orgs_org_id_apps_app_id_envs_env_id_runtime_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/runtime | Get Runtime information about the environment.
*RuntimeInfoApi* | [**orgs_org_id_apps_app_id_envs_env_id_runtime_paused_put**](docs/RuntimeInfoApi.md#orgs_org_id_apps_app_id_envs_env_id_runtime_paused_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/runtime/paused | Pause / Resume an environment.
*RuntimeInfoApi* | [**orgs_org_id_apps_app_id_envs_env_id_runtime_replicas_patch**](docs/RuntimeInfoApi.md#orgs_org_id_apps_app_id_envs_env_id_runtime_replicas_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/envs/{envId}/runtime/replicas | Set number of replicas for an environment&#x27;s modules.
*RuntimeInfoApi* | [**orgs_org_id_apps_app_id_runtime_get**](docs/RuntimeInfoApi.md#orgs_org_id_apps_app_id_runtime_get) | **GET** /orgs/{orgId}/apps/{appId}/runtime | Get Runtime information about specific environments.
*SecretStoreApi* | [**orgs_org_id_secretstores_get**](docs/SecretStoreApi.md#orgs_org_id_secretstores_get) | **GET** /orgs/{orgId}/secretstores | Get list of Secret Stores for the given organization.
*SecretStoreApi* | [**orgs_org_id_secretstores_post**](docs/SecretStoreApi.md#orgs_org_id_secretstores_post) | **POST** /orgs/{orgId}/secretstores | Create a Secret Store for the given organization.
*SecretStoreApi* | [**orgs_org_id_secretstores_store_id_delete**](docs/SecretStoreApi.md#orgs_org_id_secretstores_store_id_delete) | **DELETE** /orgs/{orgId}/secretstores/{storeId} | Delete the Secret Store.
*SecretStoreApi* | [**orgs_org_id_secretstores_store_id_get**](docs/SecretStoreApi.md#orgs_org_id_secretstores_store_id_get) | **GET** /orgs/{orgId}/secretstores/{storeId} | Get the Secret Store.
*SecretStoreApi* | [**orgs_org_id_secretstores_store_id_patch**](docs/SecretStoreApi.md#orgs_org_id_secretstores_store_id_patch) | **PATCH** /orgs/{orgId}/secretstores/{storeId} | Update the Secret Store.
*SetApi* | [**get_sets**](docs/SetApi.md#get_sets) | **GET** /orgs/{orgId}/apps/{appId}/sets | Get all Deployment Sets
*SetApi* | [**orgs_org_id_apps_app_id_sets_set_id_diff_source_set_id_get**](docs/SetApi.md#orgs_org_id_apps_app_id_sets_set_id_diff_source_set_id_get) | **GET** /orgs/{orgId}/apps/{appId}/sets/{setId}/diff/{sourceSetId} | Get the difference between 2 Deployment Sets
*SetApi* | [**orgs_org_id_apps_app_id_sets_set_id_get**](docs/SetApi.md#orgs_org_id_apps_app_id_sets_set_id_get) | **GET** /orgs/{orgId}/apps/{appId}/sets/{setId} | Get a Deployment Set
*SetApi* | [**orgs_org_id_apps_app_id_sets_set_id_post**](docs/SetApi.md#orgs_org_id_apps_app_id_sets_set_id_post) | **POST** /orgs/{orgId}/apps/{appId}/sets/{setId} | Apply a Deployment Delta to a Deployment Set
*TokenInfoApi* | [**users_user_id_tokens_get**](docs/TokenInfoApi.md#users_user_id_tokens_get) | **GET** /users/{userId}/tokens | Lists tokens associated with a user
*TokenInfoApi* | [**users_user_id_tokens_post**](docs/TokenInfoApi.md#users_user_id_tokens_post) | **POST** /users/{userId}/tokens | Creates a new static token for a user.
*TokenInfoApi* | [**users_user_id_tokens_token_id_delete**](docs/TokenInfoApi.md#users_user_id_tokens_token_id_delete) | **DELETE** /users/{userId}/tokens/{tokenId} | Deletes a specific token associated with a user
*TokenInfoApi* | [**users_user_id_tokens_token_id_get**](docs/TokenInfoApi.md#users_user_id_tokens_token_id_get) | **GET** /users/{userId}/tokens/{tokenId} | Gets a specific token associated with a user
*UserInviteApi* | [**orgs_org_id_invitations_get**](docs/UserInviteApi.md#orgs_org_id_invitations_get) | **GET** /orgs/{orgId}/invitations | List the invites issued for the organization.
*UserProfileApi* | [**current_user_get**](docs/UserProfileApi.md#current_user_get) | **GET** /current-user | Gets the extended profile of the current user
*UserProfileApi* | [**current_user_patch**](docs/UserProfileApi.md#current_user_patch) | **PATCH** /current-user | Updates the extended profile of the current user.
*UserProfileApi* | [**orgs_org_id_users_post**](docs/UserProfileApi.md#orgs_org_id_users_post) | **POST** /orgs/{orgId}/users | Creates a new service user.
*UserProfileApi* | [**tokens_get**](docs/UserProfileApi.md#tokens_get) | **GET** /tokens | DEPRECATED
*UserProfileApi* | [**tokens_token_id_delete**](docs/UserProfileApi.md#tokens_token_id_delete) | **DELETE** /tokens/{tokenId} | DEPRECATED
*UserProfileApi* | [**users_me_get**](docs/UserProfileApi.md#users_me_get) | **GET** /users/me | DEPRECATED
*UserRoleApi* | [**orgs_org_id_apps_app_id_users_get**](docs/UserRoleApi.md#orgs_org_id_apps_app_id_users_get) | **GET** /orgs/{orgId}/apps/{appId}/users | List Users with roles in an App
*UserRoleApi* | [**orgs_org_id_apps_app_id_users_post**](docs/UserRoleApi.md#orgs_org_id_apps_app_id_users_post) | **POST** /orgs/{orgId}/apps/{appId}/users | Adds a User to an Application with a Role
*UserRoleApi* | [**orgs_org_id_apps_app_id_users_user_id_delete**](docs/UserRoleApi.md#orgs_org_id_apps_app_id_users_user_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/users/{userId} | Remove the role of a User on an Application
*UserRoleApi* | [**orgs_org_id_apps_app_id_users_user_id_get**](docs/UserRoleApi.md#orgs_org_id_apps_app_id_users_user_id_get) | **GET** /orgs/{orgId}/apps/{appId}/users/{userId} | Get the role of a User on an Application
*UserRoleApi* | [**orgs_org_id_apps_app_id_users_user_id_patch**](docs/UserRoleApi.md#orgs_org_id_apps_app_id_users_user_id_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/users/{userId} | Update the role of a User on an Application
*UserRoleApi* | [**orgs_org_id_env_types_env_type_users_post**](docs/UserRoleApi.md#orgs_org_id_env_types_env_type_users_post) | **POST** /orgs/{orgId}/env-types/{envType}/users | Adds a User to an Environment Type with a Role
*UserRoleApi* | [**orgs_org_id_env_types_env_type_users_user_id_delete**](docs/UserRoleApi.md#orgs_org_id_env_types_env_type_users_user_id_delete) | **DELETE** /orgs/{orgId}/env-types/{envType}/users/{userId} | Remove the role of a User on an Environment Type
*UserRoleApi* | [**orgs_org_id_env_types_env_type_users_user_id_get**](docs/UserRoleApi.md#orgs_org_id_env_types_env_type_users_user_id_get) | **GET** /orgs/{orgId}/env-types/{envType}/users/{userId} | Get the role of a User on an Environment Type
*UserRoleApi* | [**orgs_org_id_env_types_env_type_users_user_id_patch**](docs/UserRoleApi.md#orgs_org_id_env_types_env_type_users_user_id_patch) | **PATCH** /orgs/{orgId}/env-types/{envType}/users/{userId} | Update the role of a User on an Environment Type
*UserRoleApi* | [**orgs_org_id_invitations_post**](docs/UserRoleApi.md#orgs_org_id_invitations_post) | **POST** /orgs/{orgId}/invitations | Invites a user to an Organization with a specified role.
*UserRoleApi* | [**orgs_org_id_users_get**](docs/UserRoleApi.md#orgs_org_id_users_get) | **GET** /orgs/{orgId}/users | List Users with roles in an Organization
*UserRoleApi* | [**orgs_org_id_users_user_id_delete**](docs/UserRoleApi.md#orgs_org_id_users_user_id_delete) | **DELETE** /orgs/{orgId}/users/{userId} | Remove the role of a User on an Organization
*UserRoleApi* | [**orgs_org_id_users_user_id_get**](docs/UserRoleApi.md#orgs_org_id_users_user_id_get) | **GET** /orgs/{orgId}/users/{userId} | Get the role of a User on an Organization
*UserRoleApi* | [**orgs_org_id_users_user_id_patch**](docs/UserRoleApi.md#orgs_org_id_users_user_id_patch) | **PATCH** /orgs/{orgId}/users/{userId} | Update the role of a User on an Organization
*ValueApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_delete**](docs/ValueApi.md#orgs_org_id_apps_app_id_envs_env_id_values_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/values | Delete all Shared Value for an Environment
*ValueApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_get**](docs/ValueApi.md#orgs_org_id_apps_app_id_envs_env_id_values_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/values | List Shared Values in an Environment
*ValueApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_key_delete**](docs/ValueApi.md#orgs_org_id_apps_app_id_envs_env_id_values_key_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/values/{key} | Delete Shared Value for an Environment
*ValueApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_key_patch**](docs/ValueApi.md#orgs_org_id_apps_app_id_envs_env_id_values_key_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/envs/{envId}/values/{key} | Update Shared Value for an Environment
*ValueApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_key_put**](docs/ValueApi.md#orgs_org_id_apps_app_id_envs_env_id_values_key_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/values/{key} | Update Shared Value for an Environment
*ValueApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_post**](docs/ValueApi.md#orgs_org_id_apps_app_id_envs_env_id_values_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/values | Create a Shared Value for an Environment
*ValueApi* | [**orgs_org_id_apps_app_id_values_delete**](docs/ValueApi.md#orgs_org_id_apps_app_id_values_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/values | Delete all Shared Value for an App
*ValueApi* | [**orgs_org_id_apps_app_id_values_get**](docs/ValueApi.md#orgs_org_id_apps_app_id_values_get) | **GET** /orgs/{orgId}/apps/{appId}/values | List Shared Values in an Application
*ValueApi* | [**orgs_org_id_apps_app_id_values_key_delete**](docs/ValueApi.md#orgs_org_id_apps_app_id_values_key_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/values/{key} | Delete Shared Value for an Application
*ValueApi* | [**orgs_org_id_apps_app_id_values_key_patch**](docs/ValueApi.md#orgs_org_id_apps_app_id_values_key_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/values/{key} | Update Shared Value for an Application
*ValueApi* | [**orgs_org_id_apps_app_id_values_key_put**](docs/ValueApi.md#orgs_org_id_apps_app_id_values_key_put) | **PUT** /orgs/{orgId}/apps/{appId}/values/{key} | Update Shared Value for an Application
*ValueApi* | [**orgs_org_id_apps_app_id_values_post**](docs/ValueApi.md#orgs_org_id_apps_app_id_values_post) | **POST** /orgs/{orgId}/apps/{appId}/values | Create a Shared Value for an Application
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_get**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions | List Value Set Versions in an Environment of an App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_get**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId} | Get a single Value Set Version in an Environment of an App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_purge_key_post**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_purge_key_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId}/purge/{key} | Purge the value of a specific Shared Value from the App Environment Version history.
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_key_post**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_key_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId}/restore/{key} | Restore a specific key from the Value Set Version in an Environment of an App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_post**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId}/restore | Restore a Value Set Version in an Environment of an App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_value_set_versions_get**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_value_set_versions_get) | **GET** /orgs/{orgId}/apps/{appId}/value-set-versions | List Value Set Versions in the App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_get**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_get) | **GET** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId} | Get a single Value Set Version from the App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_purge_key_post**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_purge_key_post) | **POST** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId}/purge/{key} | Purge the value of a specific Shared Value from the App Version history.
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_key_post**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_key_post) | **POST** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId}/restore/{key} | Restore a specific key from the Value Set Version in an App
*ValueSetVersionApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_post**](docs/ValueSetVersionApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_post) | **POST** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId}/restore | Restore a Value Set Version in an App
*WorkloadProfileApi* | [**create_workload_profile_chart_version**](docs/WorkloadProfileApi.md#create_workload_profile_chart_version) | **POST** /orgs/{orgId}/workload-profile-chart-versions | Add new Workload Profile Chart Version
*WorkloadProfileApi* | [**create_workload_profile_version**](docs/WorkloadProfileApi.md#create_workload_profile_version) | **POST** /orgs/{orgId}/workload-profiles/{profileQid}/versions | Add new Version of the Workload Profile
*WorkloadProfileApi* | [**get_latest_workload_profile_version**](docs/WorkloadProfileApi.md#get_latest_workload_profile_version) | **GET** /orgs/{orgId}/workload-profiles/{profileQid}/versions/latest | Latest version of the given workload profile with optional constraint.
*WorkloadProfileApi* | [**list_workload_profile_chart_versions**](docs/WorkloadProfileApi.md#list_workload_profile_chart_versions) | **GET** /orgs/{orgId}/workload-profile-chart-versions | Workload Profile Chart Versions for the given organization.
*WorkloadProfileApi* | [**list_workload_profile_versions**](docs/WorkloadProfileApi.md#list_workload_profile_versions) | **GET** /orgs/{orgId}/workload-profiles/{profileQid}/versions | List versions of the given workload profile.
*WorkloadProfileApi* | [**orgs_org_id_workload_profiles_get**](docs/WorkloadProfileApi.md#orgs_org_id_workload_profiles_get) | **GET** /orgs/{orgId}/workload-profiles | List workload profiles available to the organization.
*WorkloadProfileApi* | [**orgs_org_id_workload_profiles_post**](docs/WorkloadProfileApi.md#orgs_org_id_workload_profiles_post) | **POST** /orgs/{orgId}/workload-profiles | Create new Workload Profile
*WorkloadProfileApi* | [**orgs_org_id_workload_profiles_profile_id_versions_version_delete**](docs/WorkloadProfileApi.md#orgs_org_id_workload_profiles_profile_id_versions_version_delete) | **DELETE** /orgs/{orgId}/workload-profiles/{profileId}/versions/{version} | Delete a Workload Profile Version
*WorkloadProfileApi* | [**orgs_org_id_workload_profiles_profile_qid_delete**](docs/WorkloadProfileApi.md#orgs_org_id_workload_profiles_profile_qid_delete) | **DELETE** /orgs/{orgId}/workload-profiles/{profileQid} | Delete a Workload Profile
*WorkloadProfileApi* | [**orgs_org_id_workload_profiles_profile_qid_get**](docs/WorkloadProfileApi.md#orgs_org_id_workload_profiles_profile_qid_get) | **GET** /orgs/{orgId}/workload-profiles/{profileQid} | Get a Workload Profile
*PublicApi* | [**approve_approval_request**](docs/PublicApi.md#approve_approval_request) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/approvals/{approvalId}/approve | Approve the approval request
*PublicApi* | [**cancel_run**](docs/PublicApi.md#cancel_run) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/cancel | Cancel a Run within an Pipeline.
*PublicApi* | [**create_pipeline**](docs/PublicApi.md#create_pipeline) | **POST** /orgs/{orgId}/apps/{appId}/pipelines | Create a Pipeline within an Application.
*PublicApi* | [**create_pipeline_run**](docs/PublicApi.md#create_pipeline_run) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs | Create a run within a pipeline.
*PublicApi* | [**create_public_key**](docs/PublicApi.md#create_public_key) | **POST** /orgs/{orgId}/keys | Associate a new RSA public key to an organization.
*PublicApi* | [**create_workload_profile_chart_version**](docs/PublicApi.md#create_workload_profile_chart_version) | **POST** /orgs/{orgId}/workload-profile-chart-versions | Add new Workload Profile Chart Version
*PublicApi* | [**create_workload_profile_version**](docs/PublicApi.md#create_workload_profile_version) | **POST** /orgs/{orgId}/workload-profiles/{profileQid}/versions | Add new Version of the Workload Profile
*PublicApi* | [**current_user_get**](docs/PublicApi.md#current_user_get) | **GET** /current-user | Gets the extended profile of the current user
*PublicApi* | [**current_user_patch**](docs/PublicApi.md#current_user_patch) | **PATCH** /current-user | Updates the extended profile of the current user.
*PublicApi* | [**delete_pipeline**](docs/PublicApi.md#delete_pipeline) | **DELETE** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId} | Delete a pipeline within an application.
*PublicApi* | [**delete_public_key**](docs/PublicApi.md#delete_public_key) | **DELETE** /orgs/{orgId}/keys/{keyId} | Delete a public key associated to an organization.
*PublicApi* | [**delete_run**](docs/PublicApi.md#delete_run) | **DELETE** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId} | Deleting a completed Run within a Pipeline.
*PublicApi* | [**deny_approval_request**](docs/PublicApi.md#deny_approval_request) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/approvals/{approvalId}/deny | Deny the approval request
*PublicApi* | [**get_approval_request**](docs/PublicApi.md#get_approval_request) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/approvals/{approvalId} | Get an approval request
*PublicApi* | [**get_delta**](docs/PublicApi.md#get_delta) | **GET** /orgs/{orgId}/apps/{appId}/deltas/{deltaId} | Fetch an existing Delta
*PublicApi* | [**get_humanitec_public_keys**](docs/PublicApi.md#get_humanitec_public_keys) | **GET** /orgs/{orgId}/humanitec-keys | List all the public keys Humanitec shares with an organization.
*PublicApi* | [**get_latest_pipeline_definition_schema**](docs/PublicApi.md#get_latest_pipeline_definition_schema) | **GET** /orgs/{orgId}/pipeline-schemas/latest | Gets the latest pipeline schema
*PublicApi* | [**get_latest_workload_profile_version**](docs/PublicApi.md#get_latest_workload_profile_version) | **GET** /orgs/{orgId}/workload-profiles/{profileQid}/versions/latest | Latest version of the given workload profile with optional constraint.
*PublicApi* | [**get_pipeline**](docs/PublicApi.md#get_pipeline) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId} | Get a Pipeline within an Application.
*PublicApi* | [**get_pipeline_definition**](docs/PublicApi.md#get_pipeline_definition) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/schema | Get a pipeline schema.
*PublicApi* | [**get_public_key**](docs/PublicApi.md#get_public_key) | **GET** /orgs/{orgId}/keys/{keyId} | Retrieve a single public key associated to an organization.
*PublicApi* | [**get_public_keys**](docs/PublicApi.md#get_public_keys) | **GET** /orgs/{orgId}/keys | List all public keys associated to an organization.
*PublicApi* | [**get_run**](docs/PublicApi.md#get_run) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId} | Get a run within an pipeline.
*PublicApi* | [**get_run_job**](docs/PublicApi.md#get_run_job) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId} | List the details of a Job including Step information
*PublicApi* | [**get_sets**](docs/PublicApi.md#get_sets) | **GET** /orgs/{orgId}/apps/{appId}/sets | Get all Deployment Sets
*PublicApi* | [**list_approval_requests**](docs/PublicApi.md#list_approval_requests) | **GET** /orgs/{orgId}/apps/{appId}/approvals | List of the approval requests
*PublicApi* | [**list_pipeline_runs**](docs/PublicApi.md#list_pipeline_runs) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs | List runs within a pipeline.
*PublicApi* | [**list_pipeline_runs_by_org**](docs/PublicApi.md#list_pipeline_runs_by_org) | **GET** /orgs/{orgId}/pipeline-runs | List all pipeline runs within the Org. This can be filtered by app, pipeline, and status.
*PublicApi* | [**list_pipeline_versions**](docs/PublicApi.md#list_pipeline_versions) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/versions | List all versions of the pipeline
*PublicApi* | [**list_pipelines**](docs/PublicApi.md#list_pipelines) | **GET** /orgs/{orgId}/apps/{appId}/pipelines | List Pipelines within an Application.
*PublicApi* | [**list_pipelines_in_org**](docs/PublicApi.md#list_pipelines_in_org) | **GET** /orgs/{orgId}/pipelines | List all Pipelines within an Organization. This can be filtered by Application.
*PublicApi* | [**list_run_job_step_logs**](docs/PublicApi.md#list_run_job_step_logs) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs/{jobId}/steps/{stepIndex}/logs | Get a page of log output for a given step within a job.
*PublicApi* | [**list_run_jobs**](docs/PublicApi.md#list_run_jobs) | **GET** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/jobs | List the details of the jobs with in a pipeline run.
*PublicApi* | [**list_workload_profile_chart_versions**](docs/PublicApi.md#list_workload_profile_chart_versions) | **GET** /orgs/{orgId}/workload-profile-chart-versions | Workload Profile Chart Versions for the given organization.
*PublicApi* | [**list_workload_profile_versions**](docs/PublicApi.md#list_workload_profile_versions) | **GET** /orgs/{orgId}/workload-profiles/{profileQid}/versions | List versions of the given workload profile.
*PublicApi* | [**orgs_get**](docs/PublicApi.md#orgs_get) | **GET** /orgs | List active organizations the user has access to.
*PublicApi* | [**orgs_org_id_apps_app_id_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId} | Delete an Application
*PublicApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_metadata_archived_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_deltas_delta_id_metadata_archived_put) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId}/metadata/archived | Mark a Delta as \&quot;archived\&quot;
*PublicApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_metadata_env_id_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_deltas_delta_id_metadata_env_id_put) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId}/metadata/env_id | Change the Environment of a Delta
*PublicApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_metadata_name_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_deltas_delta_id_metadata_name_put) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId}/metadata/name | Change the name of a Delta
*PublicApi* | [**orgs_org_id_apps_app_id_deltas_delta_id_patch**](docs/PublicApi.md#orgs_org_id_apps_app_id_deltas_delta_id_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/deltas/{deltaId} | Update an existing Delta
*PublicApi* | [**orgs_org_id_apps_app_id_deltas_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_deltas_get) | **GET** /orgs/{orgId}/apps/{appId}/deltas | List Deltas in an Application
*PublicApi* | [**orgs_org_id_apps_app_id_deltas_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_deltas_post) | **POST** /orgs/{orgId}/apps/{appId}/deltas | Create a new Delta
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId} | Delete a specific Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_errors_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_errors_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys/{deployId}/errors | List errors that occurred in a Deployment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_deploy_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys/{deployId} | Get a specific Deployment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys | List Deployments in an Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_deploys_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_deploys_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/deploys | Start a new Deployment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_from_deploy_id_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_from_deploy_id_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/from_deploy_id | Rebase to a different Deployment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId} | Get a specific Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_resources_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_resources_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/resources | List Active Resources provisioned in an environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_resources_graph_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_resources_graph_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/resources/graph | Lists the resource objects that hold the information needed to provision the resources specified in the request and the resources they depend on.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_resources_type_res_id_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_resources_type_res_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/resources/{type}/{resId} | Delete Active Resources.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules | List all Automation Rules in an Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules | Create a new Automation Rule for an Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules/{ruleId} | Delete Automation Rule from an Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules/{ruleId} | Get a specific Automation Rule for an Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_rules_rule_id_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/rules/{ruleId} | Update an existing Automation Rule for an Environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_runtime_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_runtime_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/runtime | Get Runtime information about the environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_runtime_paused_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_runtime_paused_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/runtime/paused | Pause / Resume an environment.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_runtime_replicas_patch**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_runtime_replicas_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/envs/{envId}/runtime/replicas | Set number of replicas for an environment&#x27;s modules.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions | List Value Set Versions in an Environment of an App
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId} | Get a single Value Set Version in an Environment of an App
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_purge_key_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_purge_key_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId}/purge/{key} | Purge the value of a specific Shared Value from the App Environment Version history.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_key_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_key_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId}/restore/{key} | Restore a specific key from the Value Set Version in an Environment of an App
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_value_set_versions_value_set_version_id_restore_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/value-set-versions/{valueSetVersionId}/restore | Restore a Value Set Version in an Environment of an App
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_values_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/values | Delete all Shared Value for an Environment
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_values_get) | **GET** /orgs/{orgId}/apps/{appId}/envs/{envId}/values | List Shared Values in an Environment
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_key_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_values_key_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/envs/{envId}/values/{key} | Delete Shared Value for an Environment
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_key_patch**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_values_key_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/envs/{envId}/values/{key} | Update Shared Value for an Environment
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_key_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_values_key_put) | **PUT** /orgs/{orgId}/apps/{appId}/envs/{envId}/values/{key} | Update Shared Value for an Environment
*PublicApi* | [**orgs_org_id_apps_app_id_envs_env_id_values_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_env_id_values_post) | **POST** /orgs/{orgId}/apps/{appId}/envs/{envId}/values | Create a Shared Value for an Environment
*PublicApi* | [**orgs_org_id_apps_app_id_envs_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_get) | **GET** /orgs/{orgId}/apps/{appId}/envs | List all Environments.
*PublicApi* | [**orgs_org_id_apps_app_id_envs_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_envs_post) | **POST** /orgs/{orgId}/apps/{appId}/envs | Add a new Environment to an Application.
*PublicApi* | [**orgs_org_id_apps_app_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_get) | **GET** /orgs/{orgId}/apps/{appId} | Get an existing Application
*PublicApi* | [**orgs_org_id_apps_app_id_jobs_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_jobs_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/jobs | Deletes all Jobs for the Application
*PublicApi* | [**orgs_org_id_apps_app_id_runtime_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_runtime_get) | **GET** /orgs/{orgId}/apps/{appId}/runtime | Get Runtime information about specific environments.
*PublicApi* | [**orgs_org_id_apps_app_id_sets_set_id_diff_source_set_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_sets_set_id_diff_source_set_id_get) | **GET** /orgs/{orgId}/apps/{appId}/sets/{setId}/diff/{sourceSetId} | Get the difference between 2 Deployment Sets
*PublicApi* | [**orgs_org_id_apps_app_id_sets_set_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_sets_set_id_get) | **GET** /orgs/{orgId}/apps/{appId}/sets/{setId} | Get a Deployment Set
*PublicApi* | [**orgs_org_id_apps_app_id_sets_set_id_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_sets_set_id_post) | **POST** /orgs/{orgId}/apps/{appId}/sets/{setId} | Apply a Deployment Delta to a Deployment Set
*PublicApi* | [**orgs_org_id_apps_app_id_users_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_users_get) | **GET** /orgs/{orgId}/apps/{appId}/users | List Users with roles in an App
*PublicApi* | [**orgs_org_id_apps_app_id_users_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_users_post) | **POST** /orgs/{orgId}/apps/{appId}/users | Adds a User to an Application with a Role
*PublicApi* | [**orgs_org_id_apps_app_id_users_user_id_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_users_user_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/users/{userId} | Remove the role of a User on an Application
*PublicApi* | [**orgs_org_id_apps_app_id_users_user_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_users_user_id_get) | **GET** /orgs/{orgId}/apps/{appId}/users/{userId} | Get the role of a User on an Application
*PublicApi* | [**orgs_org_id_apps_app_id_users_user_id_patch**](docs/PublicApi.md#orgs_org_id_apps_app_id_users_user_id_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/users/{userId} | Update the role of a User on an Application
*PublicApi* | [**orgs_org_id_apps_app_id_value_set_versions_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_value_set_versions_get) | **GET** /orgs/{orgId}/apps/{appId}/value-set-versions | List Value Set Versions in the App
*PublicApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_get) | **GET** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId} | Get a single Value Set Version from the App
*PublicApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_purge_key_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_purge_key_post) | **POST** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId}/purge/{key} | Purge the value of a specific Shared Value from the App Version history.
*PublicApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_key_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_key_post) | **POST** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId}/restore/{key} | Restore a specific key from the Value Set Version in an App
*PublicApi* | [**orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_value_set_versions_value_set_version_id_restore_post) | **POST** /orgs/{orgId}/apps/{appId}/value-set-versions/{valueSetVersionId}/restore | Restore a Value Set Version in an App
*PublicApi* | [**orgs_org_id_apps_app_id_values_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_values_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/values | Delete all Shared Value for an App
*PublicApi* | [**orgs_org_id_apps_app_id_values_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_values_get) | **GET** /orgs/{orgId}/apps/{appId}/values | List Shared Values in an Application
*PublicApi* | [**orgs_org_id_apps_app_id_values_key_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_values_key_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/values/{key} | Delete Shared Value for an Application
*PublicApi* | [**orgs_org_id_apps_app_id_values_key_patch**](docs/PublicApi.md#orgs_org_id_apps_app_id_values_key_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/values/{key} | Update Shared Value for an Application
*PublicApi* | [**orgs_org_id_apps_app_id_values_key_put**](docs/PublicApi.md#orgs_org_id_apps_app_id_values_key_put) | **PUT** /orgs/{orgId}/apps/{appId}/values/{key} | Update Shared Value for an Application
*PublicApi* | [**orgs_org_id_apps_app_id_values_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_values_post) | **POST** /orgs/{orgId}/apps/{appId}/values | Create a Shared Value for an Application
*PublicApi* | [**orgs_org_id_apps_app_id_webhooks_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_webhooks_get) | **GET** /orgs/{orgId}/apps/{appId}/webhooks | List Webhooks
*PublicApi* | [**orgs_org_id_apps_app_id_webhooks_job_id_delete**](docs/PublicApi.md#orgs_org_id_apps_app_id_webhooks_job_id_delete) | **DELETE** /orgs/{orgId}/apps/{appId}/webhooks/{jobId} | Delete a Webhook
*PublicApi* | [**orgs_org_id_apps_app_id_webhooks_job_id_get**](docs/PublicApi.md#orgs_org_id_apps_app_id_webhooks_job_id_get) | **GET** /orgs/{orgId}/apps/{appId}/webhooks/{jobId} | Get a Webhook
*PublicApi* | [**orgs_org_id_apps_app_id_webhooks_job_id_patch**](docs/PublicApi.md#orgs_org_id_apps_app_id_webhooks_job_id_patch) | **PATCH** /orgs/{orgId}/apps/{appId}/webhooks/{jobId} | Update a Webhook
*PublicApi* | [**orgs_org_id_apps_app_id_webhooks_post**](docs/PublicApi.md#orgs_org_id_apps_app_id_webhooks_post) | **POST** /orgs/{orgId}/apps/{appId}/webhooks | Create a new Webhook
*PublicApi* | [**orgs_org_id_apps_get**](docs/PublicApi.md#orgs_org_id_apps_get) | **GET** /orgs/{orgId}/apps | List all Applications in an Organization.
*PublicApi* | [**orgs_org_id_apps_post**](docs/PublicApi.md#orgs_org_id_apps_post) | **POST** /orgs/{orgId}/apps | Add a new Application to an Organization
*PublicApi* | [**orgs_org_id_artefact_versions_artefact_version_id_get**](docs/PublicApi.md#orgs_org_id_artefact_versions_artefact_version_id_get) | **GET** /orgs/{orgId}/artefact-versions/{artefactVersionId} | Get an Artefacts Versions.
*PublicApi* | [**orgs_org_id_artefact_versions_get**](docs/PublicApi.md#orgs_org_id_artefact_versions_get) | **GET** /orgs/{orgId}/artefact-versions | List all Artefacts Versions.
*PublicApi* | [**orgs_org_id_artefact_versions_post**](docs/PublicApi.md#orgs_org_id_artefact_versions_post) | **POST** /orgs/{orgId}/artefact-versions | Register a new Artefact Version with your organization.
*PublicApi* | [**orgs_org_id_artefacts_artefact_id_delete**](docs/PublicApi.md#orgs_org_id_artefacts_artefact_id_delete) | **DELETE** /orgs/{orgId}/artefacts/{artefactId} | Delete Artefact and all related Artefact Versions
*PublicApi* | [**orgs_org_id_artefacts_artefact_id_versions_get**](docs/PublicApi.md#orgs_org_id_artefacts_artefact_id_versions_get) | **GET** /orgs/{orgId}/artefacts/{artefactId}/versions | List all Artefact Versions of an Artefact.
*PublicApi* | [**orgs_org_id_artefacts_artefact_id_versions_version_id_patch**](docs/PublicApi.md#orgs_org_id_artefacts_artefact_id_versions_version_id_patch) | **PATCH** /orgs/{orgId}/artefacts/{artefactId}/versions/{versionId} | Update Version of an Artefact.
*PublicApi* | [**orgs_org_id_artefacts_get**](docs/PublicApi.md#orgs_org_id_artefacts_get) | **GET** /orgs/{orgId}/artefacts | List all Artefacts.
*PublicApi* | [**orgs_org_id_env_types_env_type_id_delete**](docs/PublicApi.md#orgs_org_id_env_types_env_type_id_delete) | **DELETE** /orgs/{orgId}/env-types/{envTypeId} | Deletes an Environment Type
*PublicApi* | [**orgs_org_id_env_types_env_type_id_get**](docs/PublicApi.md#orgs_org_id_env_types_env_type_id_get) | **GET** /orgs/{orgId}/env-types/{envTypeId} | Get an Environment Type
*PublicApi* | [**orgs_org_id_env_types_env_type_users_post**](docs/PublicApi.md#orgs_org_id_env_types_env_type_users_post) | **POST** /orgs/{orgId}/env-types/{envType}/users | Adds a User to an Environment Type with a Role
*PublicApi* | [**orgs_org_id_env_types_env_type_users_user_id_delete**](docs/PublicApi.md#orgs_org_id_env_types_env_type_users_user_id_delete) | **DELETE** /orgs/{orgId}/env-types/{envType}/users/{userId} | Remove the role of a User on an Environment Type
*PublicApi* | [**orgs_org_id_env_types_env_type_users_user_id_get**](docs/PublicApi.md#orgs_org_id_env_types_env_type_users_user_id_get) | **GET** /orgs/{orgId}/env-types/{envType}/users/{userId} | Get the role of a User on an Environment Type
*PublicApi* | [**orgs_org_id_env_types_env_type_users_user_id_patch**](docs/PublicApi.md#orgs_org_id_env_types_env_type_users_user_id_patch) | **PATCH** /orgs/{orgId}/env-types/{envType}/users/{userId} | Update the role of a User on an Environment Type
*PublicApi* | [**orgs_org_id_env_types_get**](docs/PublicApi.md#orgs_org_id_env_types_get) | **GET** /orgs/{orgId}/env-types | List all Environment Types
*PublicApi* | [**orgs_org_id_env_types_post**](docs/PublicApi.md#orgs_org_id_env_types_post) | **POST** /orgs/{orgId}/env-types | Add a new Environment Type
*PublicApi* | [**orgs_org_id_events_get**](docs/PublicApi.md#orgs_org_id_events_get) | **GET** /orgs/{orgId}/events | List Events
*PublicApi* | [**orgs_org_id_get**](docs/PublicApi.md#orgs_org_id_get) | **GET** /orgs/{orgId} | Get the specified Organization.
*PublicApi* | [**orgs_org_id_images_get**](docs/PublicApi.md#orgs_org_id_images_get) | **GET** /orgs/{orgId}/images | List all Container Images
*PublicApi* | [**orgs_org_id_images_image_id_builds_get**](docs/PublicApi.md#orgs_org_id_images_image_id_builds_get) | **GET** /orgs/{orgId}/images/{imageId}/builds | Lists all the Builds of an Image
*PublicApi* | [**orgs_org_id_images_image_id_builds_post**](docs/PublicApi.md#orgs_org_id_images_image_id_builds_post) | **POST** /orgs/{orgId}/images/{imageId}/builds | Add a new Image Build
*PublicApi* | [**orgs_org_id_images_image_id_get**](docs/PublicApi.md#orgs_org_id_images_image_id_get) | **GET** /orgs/{orgId}/images/{imageId} | Get a specific Image Object
*PublicApi* | [**orgs_org_id_invitations_get**](docs/PublicApi.md#orgs_org_id_invitations_get) | **GET** /orgs/{orgId}/invitations | List the invites issued for the organization.
*PublicApi* | [**orgs_org_id_invitations_post**](docs/PublicApi.md#orgs_org_id_invitations_post) | **POST** /orgs/{orgId}/invitations | Invites a user to an Organization with a specified role.
*PublicApi* | [**orgs_org_id_registries_get**](docs/PublicApi.md#orgs_org_id_registries_get) | **GET** /orgs/{orgId}/registries | Lists available registries for the organization.
*PublicApi* | [**orgs_org_id_registries_post**](docs/PublicApi.md#orgs_org_id_registries_post) | **POST** /orgs/{orgId}/registries | Creates a new registry record.
*PublicApi* | [**orgs_org_id_registries_reg_id_creds_get**](docs/PublicApi.md#orgs_org_id_registries_reg_id_creds_get) | **GET** /orgs/{orgId}/registries/{regId}/creds | Returns current account credentials or secret details for the registry.
*PublicApi* | [**orgs_org_id_registries_reg_id_delete**](docs/PublicApi.md#orgs_org_id_registries_reg_id_delete) | **DELETE** /orgs/{orgId}/registries/{regId} | Deletes an existing registry record and all associated credentials and secrets.
*PublicApi* | [**orgs_org_id_registries_reg_id_get**](docs/PublicApi.md#orgs_org_id_registries_reg_id_get) | **GET** /orgs/{orgId}/registries/{regId} | Loads a registry record details.
*PublicApi* | [**orgs_org_id_registries_reg_id_patch**](docs/PublicApi.md#orgs_org_id_registries_reg_id_patch) | **PATCH** /orgs/{orgId}/registries/{regId} | Updates (patches) an existing registry record.
*PublicApi* | [**orgs_org_id_resources_account_types_get**](docs/PublicApi.md#orgs_org_id_resources_account_types_get) | **GET** /orgs/{orgId}/resources/account-types | List Resource Account Types available to the organization.
*PublicApi* | [**orgs_org_id_resources_accounts_acc_id_delete**](docs/PublicApi.md#orgs_org_id_resources_accounts_acc_id_delete) | **DELETE** /orgs/{orgId}/resources/accounts/{accId} | Delete an unused Resource Account.
*PublicApi* | [**orgs_org_id_resources_accounts_acc_id_get**](docs/PublicApi.md#orgs_org_id_resources_accounts_acc_id_get) | **GET** /orgs/{orgId}/resources/accounts/{accId} | Get a Resource Account.
*PublicApi* | [**orgs_org_id_resources_accounts_acc_id_patch**](docs/PublicApi.md#orgs_org_id_resources_accounts_acc_id_patch) | **PATCH** /orgs/{orgId}/resources/accounts/{accId} | Update a Resource Account.
*PublicApi* | [**orgs_org_id_resources_accounts_get**](docs/PublicApi.md#orgs_org_id_resources_accounts_get) | **GET** /orgs/{orgId}/resources/accounts | List Resource Accounts in the organization.
*PublicApi* | [**orgs_org_id_resources_accounts_post**](docs/PublicApi.md#orgs_org_id_resources_accounts_post) | **POST** /orgs/{orgId}/resources/accounts | Create a new Resource Account in the organization.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_criteria_criteria_id_delete**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_criteria_criteria_id_delete) | **DELETE** /orgs/{orgId}/resources/defs/{defId}/criteria/{criteriaId} | Delete a Matching Criteria from a Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_criteria_post**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_criteria_post) | **POST** /orgs/{orgId}/resources/defs/{defId}/criteria | Add a new Matching Criteria to a Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_delete**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_delete) | **DELETE** /orgs/{orgId}/resources/defs/{defId} | Delete a Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_get**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_get) | **GET** /orgs/{orgId}/resources/defs/{defId} | Get a specific Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_patch**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_patch) | **PATCH** /orgs/{orgId}/resources/defs/{defId} | Update a Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_put**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_put) | **PUT** /orgs/{orgId}/resources/defs/{defId} | Update a Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_def_id_resources_get**](docs/PublicApi.md#orgs_org_id_resources_defs_def_id_resources_get) | **GET** /orgs/{orgId}/resources/defs/{defId}/resources | List Active Resources provisioned via a specific Resource Definition.
*PublicApi* | [**orgs_org_id_resources_defs_get**](docs/PublicApi.md#orgs_org_id_resources_defs_get) | **GET** /orgs/{orgId}/resources/defs | List Resource Definitions.
*PublicApi* | [**orgs_org_id_resources_defs_post**](docs/PublicApi.md#orgs_org_id_resources_defs_post) | **POST** /orgs/{orgId}/resources/defs | Create a new Resource Definition.
*PublicApi* | [**orgs_org_id_resources_drivers_driver_id_delete**](docs/PublicApi.md#orgs_org_id_resources_drivers_driver_id_delete) | **DELETE** /orgs/{orgId}/resources/drivers/{driverId} | Delete a Resources Driver.
*PublicApi* | [**orgs_org_id_resources_drivers_driver_id_get**](docs/PublicApi.md#orgs_org_id_resources_drivers_driver_id_get) | **GET** /orgs/{orgId}/resources/drivers/{driverId} | Get a Resource Driver.
*PublicApi* | [**orgs_org_id_resources_drivers_driver_id_put**](docs/PublicApi.md#orgs_org_id_resources_drivers_driver_id_put) | **PUT** /orgs/{orgId}/resources/drivers/{driverId} | Update a Resource Driver.
*PublicApi* | [**orgs_org_id_resources_drivers_get**](docs/PublicApi.md#orgs_org_id_resources_drivers_get) | **GET** /orgs/{orgId}/resources/drivers | List Resource Drivers.
*PublicApi* | [**orgs_org_id_resources_drivers_post**](docs/PublicApi.md#orgs_org_id_resources_drivers_post) | **POST** /orgs/{orgId}/resources/drivers | Register a new Resource Driver.
*PublicApi* | [**orgs_org_id_resources_types_get**](docs/PublicApi.md#orgs_org_id_resources_types_get) | **GET** /orgs/{orgId}/resources/types | List Resource Types.
*PublicApi* | [**orgs_org_id_secretstores_get**](docs/PublicApi.md#orgs_org_id_secretstores_get) | **GET** /orgs/{orgId}/secretstores | Get list of Secret Stores for the given organization.
*PublicApi* | [**orgs_org_id_secretstores_post**](docs/PublicApi.md#orgs_org_id_secretstores_post) | **POST** /orgs/{orgId}/secretstores | Create a Secret Store for the given organization.
*PublicApi* | [**orgs_org_id_secretstores_store_id_delete**](docs/PublicApi.md#orgs_org_id_secretstores_store_id_delete) | **DELETE** /orgs/{orgId}/secretstores/{storeId} | Delete the Secret Store.
*PublicApi* | [**orgs_org_id_secretstores_store_id_get**](docs/PublicApi.md#orgs_org_id_secretstores_store_id_get) | **GET** /orgs/{orgId}/secretstores/{storeId} | Get the Secret Store.
*PublicApi* | [**orgs_org_id_secretstores_store_id_patch**](docs/PublicApi.md#orgs_org_id_secretstores_store_id_patch) | **PATCH** /orgs/{orgId}/secretstores/{storeId} | Update the Secret Store.
*PublicApi* | [**orgs_org_id_users_get**](docs/PublicApi.md#orgs_org_id_users_get) | **GET** /orgs/{orgId}/users | List Users with roles in an Organization
*PublicApi* | [**orgs_org_id_users_post**](docs/PublicApi.md#orgs_org_id_users_post) | **POST** /orgs/{orgId}/users | Creates a new service user.
*PublicApi* | [**orgs_org_id_users_user_id_delete**](docs/PublicApi.md#orgs_org_id_users_user_id_delete) | **DELETE** /orgs/{orgId}/users/{userId} | Remove the role of a User on an Organization
*PublicApi* | [**orgs_org_id_users_user_id_get**](docs/PublicApi.md#orgs_org_id_users_user_id_get) | **GET** /orgs/{orgId}/users/{userId} | Get the role of a User on an Organization
*PublicApi* | [**orgs_org_id_users_user_id_patch**](docs/PublicApi.md#orgs_org_id_users_user_id_patch) | **PATCH** /orgs/{orgId}/users/{userId} | Update the role of a User on an Organization
*PublicApi* | [**orgs_org_id_workload_profiles_get**](docs/PublicApi.md#orgs_org_id_workload_profiles_get) | **GET** /orgs/{orgId}/workload-profiles | List workload profiles available to the organization.
*PublicApi* | [**orgs_org_id_workload_profiles_post**](docs/PublicApi.md#orgs_org_id_workload_profiles_post) | **POST** /orgs/{orgId}/workload-profiles | Create new Workload Profile
*PublicApi* | [**orgs_org_id_workload_profiles_profile_id_versions_version_delete**](docs/PublicApi.md#orgs_org_id_workload_profiles_profile_id_versions_version_delete) | **DELETE** /orgs/{orgId}/workload-profiles/{profileId}/versions/{version} | Delete a Workload Profile Version
*PublicApi* | [**orgs_org_id_workload_profiles_profile_qid_delete**](docs/PublicApi.md#orgs_org_id_workload_profiles_profile_qid_delete) | **DELETE** /orgs/{orgId}/workload-profiles/{profileQid} | Delete a Workload Profile
*PublicApi* | [**orgs_org_id_workload_profiles_profile_qid_get**](docs/PublicApi.md#orgs_org_id_workload_profiles_profile_qid_get) | **GET** /orgs/{orgId}/workload-profiles/{profileQid} | Get a Workload Profile
*PublicApi* | [**put_delta**](docs/PublicApi.md#put_delta) | **PUT** /orgs/{orgId}/apps/{appId}/deltas/{deltaId} | Update an existing Delta
*PublicApi* | [**restart_run**](docs/PublicApi.md#restart_run) | **POST** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId}/runs/{runId}/restart | Restart a Run within an Pipeline by cloning it with the same trigger and inputs.
*PublicApi* | [**tokens_get**](docs/PublicApi.md#tokens_get) | **GET** /tokens | DEPRECATED
*PublicApi* | [**tokens_token_id_delete**](docs/PublicApi.md#tokens_token_id_delete) | **DELETE** /tokens/{tokenId} | DEPRECATED
*PublicApi* | [**update_pipeline**](docs/PublicApi.md#update_pipeline) | **PATCH** /orgs/{orgId}/apps/{appId}/pipelines/{pipelineId} | update a Pipeline within an Application.
*PublicApi* | [**users_me_get**](docs/PublicApi.md#users_me_get) | **GET** /users/me | DEPRECATED
*PublicApi* | [**users_user_id_tokens_get**](docs/PublicApi.md#users_user_id_tokens_get) | **GET** /users/{userId}/tokens | Lists tokens associated with a user
*PublicApi* | [**users_user_id_tokens_post**](docs/PublicApi.md#users_user_id_tokens_post) | **POST** /users/{userId}/tokens | Creates a new static token for a user.
*PublicApi* | [**users_user_id_tokens_token_id_delete**](docs/PublicApi.md#users_user_id_tokens_token_id_delete) | **DELETE** /users/{userId}/tokens/{tokenId} | Deletes a specific token associated with a user
*PublicApi* | [**users_user_id_tokens_token_id_get**](docs/PublicApi.md#users_user_id_tokens_token_id_get) | **GET** /users/{userId}/tokens/{tokenId} | Gets a specific token associated with a user

## Documentation For Models

 - [AWSAuthRequest](docs/AWSAuthRequest.md)
 - [AWSSMRequest](docs/AWSSMRequest.md)
 - [AWSSMResponse](docs/AWSSMResponse.md)
 - [AccountCredsRequest](docs/AccountCredsRequest.md)
 - [AccountTypeRequest](docs/AccountTypeRequest.md)
 - [AccountTypeResponse](docs/AccountTypeResponse.md)
 - [ActiveResourceRequest](docs/ActiveResourceRequest.md)
 - [ActiveResourceResponse](docs/ActiveResourceResponse.md)
 - [AddArtefactVersionPayloadRequest](docs/AddArtefactVersionPayloadRequest.md)
 - [ApplicationCreationRequest](docs/ApplicationCreationRequest.md)
 - [ApplicationRequest](docs/ApplicationRequest.md)
 - [ApplicationResponse](docs/ApplicationResponse.md)
 - [ApprovalRequest](docs/ApprovalRequest.md)
 - [ArtefactRequest](docs/ArtefactRequest.md)
 - [ArtefactResponse](docs/ArtefactResponse.md)
 - [ArtefactVersionRequest](docs/ArtefactVersionRequest.md)
 - [ArtefactVersionResponse](docs/ArtefactVersionResponse.md)
 - [AutomationRuleRequest](docs/AutomationRuleRequest.md)
 - [AutomationRuleResponse](docs/AutomationRuleResponse.md)
 - [AzureAuthRequest](docs/AzureAuthRequest.md)
 - [AzureKVRequest](docs/AzureKVRequest.md)
 - [AzureKVResponse](docs/AzureKVResponse.md)
 - [ClusterSecretRequest](docs/ClusterSecretRequest.md)
 - [ClusterSecretResponse](docs/ClusterSecretResponse.md)
 - [ClusterSecretsMapRequest](docs/ClusterSecretsMapRequest.md)
 - [ClusterSecretsMapResponse](docs/ClusterSecretsMapResponse.md)
 - [ControllerRequest](docs/ControllerRequest.md)
 - [ControllerResponse](docs/ControllerResponse.md)
 - [CreateDriverRequestRequest](docs/CreateDriverRequestRequest.md)
 - [CreateResourceAccountRequestRequest](docs/CreateResourceAccountRequestRequest.md)
 - [CreateResourceDefinitionRequestRequest](docs/CreateResourceDefinitionRequestRequest.md)
 - [CreateSecretStorePayloadRequest](docs/CreateSecretStorePayloadRequest.md)
 - [DeltaMetadataRequest](docs/DeltaMetadataRequest.md)
 - [DeltaMetadataResponse](docs/DeltaMetadataResponse.md)
 - [DeltaRequest](docs/DeltaRequest.md)
 - [DeltaResponse](docs/DeltaResponse.md)
 - [DeployConditionRequest](docs/DeployConditionRequest.md)
 - [DeployConditionResponse](docs/DeployConditionResponse.md)
 - [DeploymentErrorRequest](docs/DeploymentErrorRequest.md)
 - [DeploymentErrorResponse](docs/DeploymentErrorResponse.md)
 - [DeploymentRequest](docs/DeploymentRequest.md)
 - [DeploymentResponse](docs/DeploymentResponse.md)
 - [DriverDefinitionRequest](docs/DriverDefinitionRequest.md)
 - [DriverDefinitionResponse](docs/DriverDefinitionResponse.md)
 - [EnvironmentBaseRequest](docs/EnvironmentBaseRequest.md)
 - [EnvironmentBaseResponse](docs/EnvironmentBaseResponse.md)
 - [EnvironmentDefinitionRequest](docs/EnvironmentDefinitionRequest.md)
 - [EnvironmentRequest](docs/EnvironmentRequest.md)
 - [EnvironmentResponse](docs/EnvironmentResponse.md)
 - [EnvironmentRuntimeInfoResponse](docs/EnvironmentRuntimeInfoResponse.md)
 - [EnvironmentTypeRequest](docs/EnvironmentTypeRequest.md)
 - [EnvironmentTypeResponse](docs/EnvironmentTypeResponse.md)
 - [ErrorInfoResponse](docs/ErrorInfoResponse.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [EventBaseRequest](docs/EventBaseRequest.md)
 - [EventBaseResponse](docs/EventBaseResponse.md)
 - [EventResponse](docs/EventResponse.md)
 - [GCPAuthRequest](docs/GCPAuthRequest.md)
 - [GCPSMRequest](docs/GCPSMRequest.md)
 - [GCPSMResponse](docs/GCPSMResponse.md)
 - [HumanitecErrorResponse](docs/HumanitecErrorResponse.md)
 - [HumanitecPublicKey](docs/HumanitecPublicKey.md)
 - [HumanitecRequest](docs/HumanitecRequest.md)
 - [HumanitecResponse](docs/HumanitecResponse.md)
 - [ImageBuildRequest](docs/ImageBuildRequest.md)
 - [ImageBuildResponse](docs/ImageBuildResponse.md)
 - [ImageRequest](docs/ImageRequest.md)
 - [ImageResponse](docs/ImageResponse.md)
 - [ImagesRegistryCredsRequest](docs/ImagesRegistryCredsRequest.md)
 - [ImagesRegistryCredsResponse](docs/ImagesRegistryCredsResponse.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [JSONFieldRequest](docs/JSONFieldRequest.md)
 - [JSONFieldResponse](docs/JSONFieldResponse.md)
 - [JSONPatchRequest](docs/JSONPatchRequest.md)
 - [JSONPatchResponse](docs/JSONPatchResponse.md)
 - [JSONPatchesResponse](docs/JSONPatchesResponse.md)
 - [LogoResponse](docs/LogoResponse.md)
 - [ManifestRequest](docs/ManifestRequest.md)
 - [ManifestResponse](docs/ManifestResponse.md)
 - [MatchingCriteriaRequest](docs/MatchingCriteriaRequest.md)
 - [MatchingCriteriaResponse](docs/MatchingCriteriaResponse.md)
 - [MatchingCriteriaRuleRequest](docs/MatchingCriteriaRuleRequest.md)
 - [ModuleDeltasRequest](docs/ModuleDeltasRequest.md)
 - [ModuleDeltasResponse](docs/ModuleDeltasResponse.md)
 - [ModuleRequest](docs/ModuleRequest.md)
 - [ModuleResponse](docs/ModuleResponse.md)
 - [NewServiceUserRequest](docs/NewServiceUserRequest.md)
 - [NodeBodyResponse](docs/NodeBodyResponse.md)
 - [OrgIdWorkloadprofilechartversionsBody](docs/OrgIdWorkloadprofilechartversionsBody.md)
 - [OrganizationRequest](docs/OrganizationRequest.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [PatchResourceDefinitionRequestRequest](docs/PatchResourceDefinitionRequestRequest.md)
 - [Pipeline](docs/Pipeline.md)
 - [PipelineVersion](docs/PipelineVersion.md)
 - [PlainDeltaResponse](docs/PlainDeltaResponse.md)
 - [PodStateRequest](docs/PodStateRequest.md)
 - [PodStateResponse](docs/PodStateResponse.md)
 - [ProvisionDependenciesRequest](docs/ProvisionDependenciesRequest.md)
 - [ProvisionDependenciesResponse](docs/ProvisionDependenciesResponse.md)
 - [PublicKey](docs/PublicKey.md)
 - [RegistryCredsResponse](docs/RegistryCredsResponse.md)
 - [RegistryRequest](docs/RegistryRequest.md)
 - [RegistryResponse](docs/RegistryResponse.md)
 - [ResourceAccountRequest](docs/ResourceAccountRequest.md)
 - [ResourceAccountResponse](docs/ResourceAccountResponse.md)
 - [ResourceDefinitionChangeResponse](docs/ResourceDefinitionChangeResponse.md)
 - [ResourceDefinitionRequest](docs/ResourceDefinitionRequest.md)
 - [ResourceDefinitionResponse](docs/ResourceDefinitionResponse.md)
 - [ResourceProvisionRequestRequest](docs/ResourceProvisionRequestRequest.md)
 - [ResourceTypeRequest](docs/ResourceTypeRequest.md)
 - [ResourceTypeResponse](docs/ResourceTypeResponse.md)
 - [RoleRequest](docs/RoleRequest.md)
 - [RunCreateRequest](docs/RunCreateRequest.md)
 - [RunJobListResponse](docs/RunJobListResponse.md)
 - [RunJobResponse](docs/RunJobResponse.md)
 - [RunJobStep](docs/RunJobStep.md)
 - [RunJobStepLog](docs/RunJobStepLog.md)
 - [RunResponse](docs/RunResponse.md)
 - [RuntimeInfoRequest](docs/RuntimeInfoRequest.md)
 - [RuntimeInfoResponse](docs/RuntimeInfoResponse.md)
 - [SecretReference](docs/SecretReference.md)
 - [SecretStoreRequest](docs/SecretStoreRequest.md)
 - [SecretStoreResponse](docs/SecretStoreResponse.md)
 - [SetRequest](docs/SetRequest.md)
 - [SetResponse](docs/SetResponse.md)
 - [TokenDefinitionRequest](docs/TokenDefinitionRequest.md)
 - [TokenInfoRequest](docs/TokenInfoRequest.md)
 - [TokenInfoResponse](docs/TokenInfoResponse.md)
 - [TokenResponse](docs/TokenResponse.md)
 - [UpdateActionRequest](docs/UpdateActionRequest.md)
 - [UpdateActionResponse](docs/UpdateActionResponse.md)
 - [UpdateArtefactVersionPayloadRequest](docs/UpdateArtefactVersionPayloadRequest.md)
 - [UpdateDriverRequestRequest](docs/UpdateDriverRequestRequest.md)
 - [UpdateResourceAccountRequestRequest](docs/UpdateResourceAccountRequestRequest.md)
 - [UpdateResourceDefinitionRequestRequest](docs/UpdateResourceDefinitionRequestRequest.md)
 - [UpdateSecretStorePayloadRequest](docs/UpdateSecretStorePayloadRequest.md)
 - [UserInviteRequestRequest](docs/UserInviteRequestRequest.md)
 - [UserInviteResponse](docs/UserInviteResponse.md)
 - [UserProfileExtendedRequest](docs/UserProfileExtendedRequest.md)
 - [UserProfileExtendedResponse](docs/UserProfileExtendedResponse.md)
 - [UserProfileRequest](docs/UserProfileRequest.md)
 - [UserProfileResponse](docs/UserProfileResponse.md)
 - [UserRoleRequest](docs/UserRoleRequest.md)
 - [UserRoleResponse](docs/UserRoleResponse.md)
 - [ValueCreatePayloadRequest](docs/ValueCreatePayloadRequest.md)
 - [ValueEditPayloadRequest](docs/ValueEditPayloadRequest.md)
 - [ValuePatchPayloadRequest](docs/ValuePatchPayloadRequest.md)
 - [ValueRequest](docs/ValueRequest.md)
 - [ValueResponse](docs/ValueResponse.md)
 - [ValueSetActionPayloadRequest](docs/ValueSetActionPayloadRequest.md)
 - [ValueSetResponse](docs/ValueSetResponse.md)
 - [ValueSetVersionResponse](docs/ValueSetVersionResponse.md)
 - [ValueSetVersionResultOf](docs/ValueSetVersionResultOf.md)
 - [ValueSource](docs/ValueSource.md)
 - [ValuesSecretsRefsRequest](docs/ValuesSecretsRefsRequest.md)
 - [ValuesSecretsRefsResponse](docs/ValuesSecretsRefsResponse.md)
 - [VaultAuthRequest](docs/VaultAuthRequest.md)
 - [VaultRequest](docs/VaultRequest.md)
 - [VaultResponse](docs/VaultResponse.md)
 - [WebhookRequest](docs/WebhookRequest.md)
 - [WebhookResponse](docs/WebhookResponse.md)
 - [WebhookUpdateResponse](docs/WebhookUpdateResponse.md)
 - [WorkloadProfileChartReference](docs/WorkloadProfileChartReference.md)
 - [WorkloadProfileChartVersionResponse](docs/WorkloadProfileChartVersionResponse.md)
 - [WorkloadProfileRequest](docs/WorkloadProfileRequest.md)
 - [WorkloadProfileResponse](docs/WorkloadProfileResponse.md)
 - [WorkloadProfileVersionRequest](docs/WorkloadProfileVersionRequest.md)
 - [WorkloadProfileVersionResponse](docs/WorkloadProfileVersionResponse.md)
 - [WorkloadProfileVersionSpecDefinition](docs/WorkloadProfileVersionSpecDefinition.md)
 - [WorkloadProfileVersionSpecDefinitionProperties](docs/WorkloadProfileVersionSpecDefinitionProperties.md)
 - [WorkloadProfileVersionSpecDefinitionProperty](docs/WorkloadProfileVersionSpecDefinitionProperty.md)
 - [WorkloadProfileVersionSpecDefinitionPropertyType](docs/WorkloadProfileVersionSpecDefinitionPropertyType.md)
 - [WorkloadProfileVersionSpecDefinitionPropertyUIHints](docs/WorkloadProfileVersionSpecDefinitionPropertyUIHints.md)
 - [WorkloadProfileVersionSpecDefinitionRuntimeProperty](docs/WorkloadProfileVersionSpecDefinitionRuntimeProperty.md)
 - [WorkloadProfileVersionSpecDefinitionRuntimePropertyType](docs/WorkloadProfileVersionSpecDefinitionRuntimePropertyType.md)

## Documentation For Authorization

## sso_auth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

Client documentation: markus.i.sverige@googlemail.com
Original openapi specification: apiteam@humanitec.com
